@@ -659,6 +659,30 @@ impl Parser {
             )));
         }
 
+        if filter_type == "U8SetFromValueStateFilter" {
+            if arguments.len() != 1 {
+                return Err(ParserError::WrongArgumentCount);
+            }
+
+            return Ok(Box::new(U8SetFromValueStateFilter::new(
+                arguments[0]
+                    .try_into()
+                    .map_err(|_| ParserError::DataError)?,
+            )));
+        }
+
+        if filter_type == "BoolFlipStateFilter" {
+            if arguments.len() != 1 {
+                return Err(ParserError::WrongArgumentCount);
+            }
+
+            return Ok(Box::new(BoolFlipStateFilter::new(
+                arguments[0]
+                    .try_into()
+                    .map_err(|_| ParserError::DataError)?,
+            )));
+        }
+
         Err(ParserError::UnknownFilter(filter_type))
     }
 
